# Calendário dos Vestibulares do Brasil


[![image](https://img.shields.io/pypi/v/calvestbr.svg)](https://pypi.python.org/pypi/calvestbr)


**Este Framework tem o objetivo de auxiliar os jovens estudantes que estão prestes a ingressar na universidade a se organizarem quanto as datas de vestibulares.**


-   Free software: MIT license
-   Documentation: https://github.com/Marina-Lara/calvestbr
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
